==> subscript-0.17.0.tar.gz: subscript-0.17.0/README.md <==
# subscript

[![subscript](https://github.com/equinor/subscript/actions/workflows/subscript.yml/badge.svg)](https://github.com/equinor/subscript/actions/workflows/subscript.yml)
[![codecov](https://codecov.io/gh/equinor/subscript/branch/master/graph/badge.svg)](https://codecov.io/gh/equinor/subscript)
![Python Version](https://img.shields.io/badge/python-3.8%20|%203.9-blue.svg)
[![License: GPL v3](https://img.shields.io/github/license/equinor/subscript)](https://www.gnu.org/licenses/gpl-3.0)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

**subscript** is Equinor's collection of scripts used for subsurface reservoir modelling.

---

## Quick Reference

* [**Documentation**](https://equinor.github.io/subscript)
* [**Installation**](#installation)
* [**Usage**](#usage)
* [**Contribution**](https://equinor.github.io/subscript/contribution.html)

---

## Installation

subscript is not presently available on PyPI so it must be manually installed.

```sh
git clone git@github.com:equinor/subscript
cd subscript
pip install .
```

## Usage

As a collection of utilities subscript has many different invocations and
usages. It is recommended to visit the [documentation](#documentation)
for a complete overview.

Note that some of these utilities may depend upon commercial third-party
software.


## Developing & Contribution

All contributions are welcome. Please see the
[Contribution document](https://equinor.github.io/subscript/contribution.html)
for more details and instructions for getting started.


## Documentation

The documentation can be found at https://equinor.github.io/subscript

==> subscript-0.17.1.tar.gz: subscript-0.17.1/README.md <==
# subscript

[![subscript](https://github.com/equinor/subscript/actions/workflows/subscript.yml/badge.svg)](https://github.com/equinor/subscript/actions/workflows/subscript.yml)
[![codecov](https://codecov.io/gh/equinor/subscript/branch/master/graph/badge.svg)](https://codecov.io/gh/equinor/subscript)
![Python Version](https://img.shields.io/badge/python-3.8%20|%203.9%20|%203.10-blue.svg)
[![License: GPL v3](https://img.shields.io/github/license/equinor/subscript)](https://www.gnu.org/licenses/gpl-3.0)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

**subscript** is Equinor's collection of scripts used for subsurface reservoir modelling.

---

## Quick Reference

* [**Documentation**](https://equinor.github.io/subscript)
* [**Installation**](#installation)
* [**Usage**](#usage)
* [**Contributing**](https://equinor.github.io/subscript/contributing.html)

---

## Installation

subscript can be installed via pip

```sh
pip install subscript
```

## Usage

As a collection of utilities subscript has many different invocations and
usages. It is recommended to visit the
[documentation](https://equinor.github.io/subscript)
for a complete overview.

Note that some of these utilities may depend upon commercial third-party
software.


## Developing & Contributing

All contributions are welcome. Please see the
[Contributing document](https://equinor.github.io/subscript/contributing.html)
for more details and instructions for getting started.


## Documentation

The documentation can be found at https://equinor.github.io/subscript
